@@ -141,6 +141,7 @@ class get_data:
         self.convert_units_avg_con()
         self.convert_units_biomass()
     #print(dv_resp)
+    # TODO remove this function
     def radius_key(self,timestep):
         """
         Generate the appropriate key for a radius at a given timestep
@@ -155,6 +156,7 @@ class get_data:
         >>> radius_key(ts)
         """
         return(f"radius{timestep}")
+        # TODO speed up calculate of biomass
     def single_cell_growth(self,timepoint=0):
         """
         Extract single cell biomass over time from the HDF5 data. 
@@ -175,7 +177,7 @@ class get_data:
                 # make sure cell id matches id of interest
                 i = np.where(arr == c)[0][0]
                 # get radius
-                radius = self.h5[self.radius_key(t)][i]
+                radius = self.h5['radius'][t][i]
                 volume = 4/3*np.pi*radius**3 #volume in m^3
                 # get celltype
                 celltype=self.h5['type'][t][i]
@@ -230,7 +232,7 @@ class get_data:
                 Dataframe containing ID, type, Distance
         """
         # TODO Speed up or parallelize this computation
-        df = self.positions.set_index(['Timepoint','ID'])
+        df = self.get_positions(timepoint)
         temp = (df[df.ID ==id][['x','y','z']].squeeze() - df[df.ID !=id][['x','y','z']])**2
         dist = pd.Series(np.sqrt(temp.x + temp.y + temp.z),name='Distance')
         return pd.concat([df[df.ID !=id][['ID','type']],dist],axis=1).reset_index(drop=True)
